@@ -18,7 +18,7 @@ use     Params::Util          qw( _IDENTIFIER _STRING            );
 use     File::Spec::Functions qw( catdir                         );
 require Perl::Dist::WiX::Directory;
 
-use version; $VERSION = qv('0.15');
+use version; $VERSION = qv('0.16');
 #>>>
 #####################################################################
 # Accessors:
@@ -172,10 +172,15 @@ sub initialize_tree {
 		  licenses\pexports
 		  perl\bin
 		  perl\lib
+		  perl\lib\Archive
 		  perl\lib\B
 		  perl\lib\Compress
 		  perl\lib\CPAN
 		  perl\lib\CPAN\API
+		  perl\lib\CPANPLUS
+		  perl\lib\CPANPLUS\Dist
+		  perl\lib\CPANPLUS\Internals
+		  perl\lib\Devel
 		  perl\lib\Digest
 		  perl\lib\ExtUtils
 		  perl\lib\File
@@ -184,10 +189,23 @@ sub initialize_tree {
 		  perl\lib\IO
 		  perl\lib\IO\Compress
 		  perl\lib\IO\Uncompress
+		  perl\lib\IPC
+		  perl\lib\Locale
+		  perl\lib\Locale\Maketext
+		  perl\lib\Log
+		  perl\lib\Log\Message
+		  perl\lib\Math
+		  perl\lib\Math\BigInt
 		  perl\lib\Module
 		  perl\lib\Module\Build
+		  perl\lib\Net
 		  perl\lib\Pod
+		  perl\lib\Term
 		  perl\lib\Test
+		  perl\lib\Test\Harness
+		  perl\lib\Text
+		  perl\lib\Thread
+		  perl\lib\Tie
 		  perl\lib\Time
 		  perl\lib\autodie
 		  perl\lib\auto
